@@ -3,13 +3,16 @@ import os
 import sys
 import tkinter as tk
 from tkinter import IntVar, Radiobutton, filedialog, messagebox, ttk
+from typing import Dict
 
 import numpy as np
 import Pmw
+from skimage.color import label2rgb
+from skimage.measure import label
 
 from dosma.cli import SUPPORTED_QUANTITATIVE_VALUES, SUPPORTED_SCAN_TYPES, parse_args
-from dosma.data_io import format_io_utils as fio_utils
-from dosma.data_io.orientation import AXIAL, CORONAL, SAGITTAL
+from dosma.core.io import format_io_utils as fio_utils
+from dosma.core.orientation import AXIAL, CORONAL, SAGITTAL
 from dosma.gui.dosma_gui import ScanReader
 from dosma.gui.gui_utils.filedialog_reader import FileDialogReader
 from dosma.gui.im_viewer import IndexTracker
@@ -19,12 +22,12 @@ from dosma.msk import knee
 import matplotlib
 import matplotlib.pyplot as plt
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg, NavigationToolbar2Tk
-from skimage.color import label2rgb
-from skimage.measure import label
 
 matplotlib.use("TkAgg")
 LARGE_FONT = ("Verdana", 12)
 
+_logger = logging.getLogger(__name__)
+
 
 class DosmaViewer(tk.Tk):
     def __init__(self, *args, **kwargs):
@@ -100,8 +103,8 @@ class AnalysisFrame(tk.Frame):
     def __init__(self, parent, controller):
         tk.Frame.__init__(self, parent)
 
-        self.manager = dict()
-        self.gui_manager = dict()
+        self.manager: Dict = {}
+        self.gui_manager: Dict = {}
         self.balloon = Pmw.Balloon()
 
         self.__init_manager()
@@ -271,8 +274,8 @@ class DosmaFrame(tk.Frame):
 
         self.file_dialog_reader = FileDialogReader()
 
-        self.manager = dict()
-        self.gui_manager = dict()
+        self.manager: Dict = {}
+        self.gui_manager: Dict = {}
         self.balloon = Pmw.Balloon()
 
         self.__init_manager()
@@ -328,7 +331,7 @@ class DosmaFrame(tk.Frame):
                 action_str,
             )
 
-            logging.info("CMD LINE INPUT: %s" % str_f)
+            _logger.info("CMD LINE INPUT: %s" % str_f)
 
             parse_args(str_f.split())
         except Exception as e:
@@ -469,7 +472,7 @@ class PageThree(tk.Frame):
     def __init__(self, parent, controller):
         tk.Frame.__init__(self, parent)
         self._im_display = None
-        self.binding_vars = dict()
+        self.binding_vars: Dict = {}
         fig, ax = plt.subplots(1, 1)
         X = np.random.rand(20, 20, 40)
 
@@ -508,7 +511,7 @@ class PageThree(tk.Frame):
         orientation_var = IntVar(0)
         orientation_var.trace_add("write", self.__reformat_callback)
         count = 0
-        for text, value in self._ORIENTATIONS:
+        for text, _value in self._ORIENTATIONS:
             b = Radiobutton(self, text=text, variable=orientation_var, value=count)
             b.pack(side=tk.TOP, anchor="w")
             count += 1
