@@ -1,16 +1,17 @@
 import os
 from abc import ABC, abstractmethod
+from typing import Union
 
 import numpy as np
 import pandas as pd
 import scipy.ndimage as sni
 
-from dosma.data_io import format_io_utils as fio_utils
-from dosma.data_io.format_io import ImageDataFormat
-from dosma.data_io.med_volume import MedicalVolume
-from dosma.data_io.orientation import SAGITTAL
+from dosma.core.io import format_io_utils as fio_utils
+from dosma.core.io.format_io import ImageDataFormat
+from dosma.core.med_volume import MedicalVolume
+from dosma.core.orientation import SAGITTAL
+from dosma.core.quant_vals import QuantitativeValue, QuantitativeValueType
 from dosma.defaults import preferences
-from dosma.quant_vals import QuantitativeValue, QuantitativeValueType
 from dosma.utils import io_utils
 
 WEIGHTS_FILE_EXT = "h5"
@@ -51,7 +52,7 @@ class Tissue(ABC):
     def __init__(self, weights_dir: str = None, medial_to_lateral: bool = None):
         self.pid = None
         self.__mask__ = None
-        self.quant_vals = dict()
+        self.quant_vals = {}
         self.weights_file_path = None
 
         if weights_dir is not None:
@@ -63,7 +64,7 @@ class Tissue(ABC):
         self.quantitative_values = []
 
     @abstractmethod
-    def split_regions(self, base_map: np.ndarray):
+    def split_regions(self, base_map: Union[np.ndarray, MedicalVolume]):
         """Split mask into anatomical regions.
 
         Args:
@@ -199,6 +200,16 @@ class Tissue(ABC):
         """
         pass
 
+    def save_quant_data(self, dirpath: str):
+        """Save quantitative data generated for this tissue.
+
+        Does not save mask or quantitative parameter map.
+
+        Args:
+            dirpath (str): Directory path to tissue data.
+        """
+        return self.__save_quant_data__(dirpath)
+
     def load_data(self, load_dir_path: str):
         """Load data for tissue.
 
@@ -244,7 +255,7 @@ class Tissue(ABC):
             mask (MedicalVolume): Binary mask of segmented tissue.
         """
         assert type(mask) is MedicalVolume, "mask for tissue must be of type MedicalVolume"
-        mask.reformat(SAGITTAL, inplace=True)
+        mask = mask.reformat(SAGITTAL)
         self.__mask__ = mask
 
     def get_mask(self):
@@ -305,7 +316,7 @@ class Tissue(ABC):
 
 
 def largest_cc(mask, num=1):
-    """ Return the largest `num` connected component(s) of a 3D mask array.
+    """Return the largest `num` connected component(s) of a 3D mask array.
 
     Args:
         mask (np.ndarray): 3D mask array (`np.bool` or `np.[u]int`).
